<?php

namespace Drupal\uswds_alert\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\uswds_alert\UswdsAlertRendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Implements SiteAlertBlock class.
 *
 * @Block(
 *   id = "uswds_alert_block",
 *   admin_label = @Translation("USWDS Alerts"),
 * )
 */
class UswdsAlert extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The alert placeholder rendering service.
   *
   * @var \Drupal\uswds_alert\UswdsAlertRendererInterface
   */
  protected $renderer;

  /**
   * Constructor.
   *
   * @param array $configuration
   *   Block configuration.
   * @param string $plugin_id
   *   Block plugin id.
   * @param mixed $plugin_definition
   *   Block plugin configuration.
   * @param \Drupal\uswds_alert\UswdsAlertRendererInterface $renderer
   *   Alert placeholder rendering service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, UswdsAlertRendererInterface $renderer) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('uswds_alert.uswds_alert_renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $form['visibility_message'] = [
      '#type' => 'item',
      '#title' => $this->t('Note: USWDS Alert block visibility'),
      '#description' => $this->t(
        'This block should be placed near the top of content.  It will only display alerts that are of the class USWDS Alert.'
      ),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    // In block context, ignore admin vs. non-admin distinction.
    $id = $this->getPluginId();
    return $this->renderer->buildBlock($id, FALSE);
  }

}
