<?php

namespace Drupal\uswds_alert;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\sitewide_alert\SitewideAlertRenderer;

/**
 * USWDS Alert placeholder render array builder service.
 *
 * Used by blocks.
 */
class UswdsAlertRenderer extends SitewideAlertRenderer implements UswdsAlertRendererInterface {

  /**
   * {@inheritdoc}
   */
  public function buildBlock(string $block_id, bool $adminAware = TRUE): array {
    $cacheMetadata = CacheableMetadata::createFromObject($this->config)
      ->addCacheContexts(['user.permissions']);

    // Do not show alert on admin pages if we are not configured to do so
    // or when we don't have enough permissions.
    if (!$this->currentUser->hasPermission('view published sitewide alert entities')
      || ($adminAware && !$this->config->get('show_on_admin') && $this->adminContext->isAdminRoute())) {
      // Populate an empty render array with cache-metadata to force it to
      // invalidate when settings change.
      $build = [];
      $cacheMetadata->applyTo($build);
      return $build;
    }
    $data_id = self::mapBlockId($block_id);

    $build = [
      '#markup' => "<div data-{$data_id}></div>",
      '#attached' => [
        'library' => [
          'sitewide_alert/init',
        ],
        'drupalSettings' => [
          'sitewideAlert' => [
            'refreshInterval' => (int) ($this->config->get('refresh_interval') ?? 15) * 1000,
            'automaticRefresh' => ($this->config->get('automatic_refresh') == 1),
          ],
        ],
      ],
    ];
    $cacheMetadata->applyTo($build);
    return $build;
  }

  /**
   * Maps the block ID to a specific configuration or behavior.
   *
   * @param string $block_id
   *   The block ID to map.
   *
   * @return string|null
   *   The mapped value or default sitewide-alert if no mapping exists.
   */
  public static function mapBlockId(string $block_id): ?string {
    $mapping = [
      'non_uswds_alert_block' => 'sitewide-alert',
      'uswds_site_alert_block' => 'uswds-site-alert',
      'uswds_alert_block' => 'uswds-alert',
    ];

    return $mapping[$block_id] ?? 'sitewide-alert';
  }

}
