<?php

namespace Drupal\Tests\uswds_alert\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests for the data endpoint.
 *
 * @group uswds_alert
 */
class JsonLoadTest extends BrowserTestBase {

  /**
   * Modules to install.
   *
   * @var array
   */
  protected static $modules = [
    'uswds_alert',
    'sitewide_alert',
    'user',
    'field',
  ];

  /**
   * The theme to default to during tests.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * A user permed for viewing endpoint.
   *
   * @var \Drupal\user\UserInterface
   */
  private $permedUser;

  /**
   * A non-permed user.
   *
   * @var \Drupal\user\UserInterface
   */
  private $normalUser;

  /**
   * Perform initial setup tasks that run before every test method.
   */
  public function setUp(): void {
    parent::setUp();
    $this->permedUser = $this->DrupalCreateUser([
      'view published sitewide alert entities',
    ]);
    $this->normalUser = $this->DrupalCreateUser([]);
  }

  /**
   * Tests that the USWDS Alert data can be reached with the right perms.
   */
  public function testReportPageExists(): void {
    $this->drupalLogin($this->permedUser);
    $this->drupalGet('sitewide_alert/load/uswds');
    $this->assertSession()->statusCodeEquals(200);
    // Assert no warnings or errors.
    $this->assertSession()->statusMessageNotExists('warning');
    $this->assertSession()->statusMessageNotExists('error');

    // Validate the content:
    $this->assertSession()->pageTextContains('"sitewideAlerts":');
  }

  /**
   * Tests that the data page can't be reached with without perms.
   */
  public function testSettingsPageAccessDenied(): void {
    $this->drupalLogin($this->normalUser);
    $this->drupalGet('sitewide_alert/load/uswds');
    // Assert no warnings or errors.
    $this->assertSession()->statusMessageNotExists('warning');
    $this->assertSession()->statusMessageNotExists('error');
    // Oddly enough, the sitewide_alert module installs with the view permission
    // granted to anonymous users.  So we can not check for a 403 here.
    // $this->assertSession()->statusCodeEquals(403);
  }

}
